OC.L10N.register(
    "settings",
    {
    "Private" : "Yksityinen",
    "Local" : "Paikallinen",
    "Only visible to people on this instance and guests" : "Vain näkyvissä tämän instanssin ihmisille ja vieraille",
    "Federated" : "Federoitu",
    "Only synchronize to trusted servers" : "Synkronoi vain luotetulle palvelimelle",
    "Published" : "Julkaistu",
    "Verify" : "Vahvista",
    "Verifying …" : "Vahvistetaan…",
    "Unable to change password" : "Salasanan vaihto ei onnistunut",
    "Very weak password" : "Erittäin heikko salasana",
    "Weak password" : "Heikko salasana",
    "So-so password" : "Kohtalainen salasana",
    "Good password" : "Hyvä salasana",
    "Strong password" : "Vahva salasana",
    "Groups" : "Ryhmät",
    "Group list is empty" : "Ryhmälista on tyhjä",
    "Unable to retrieve the group list" : "Ryhmälistaa ei voitu noutaa",
    "{actor} added you to group {group}" : "{actor} lisäsi sinut ryhmään {group}",
    "You added {user} to group {group}" : "Lisäsit käyttäjän {user} ryhmään {group}",
    "{actor} added {user} to group {group}" : "{actor} lisäsi käyttäjän {user} ryhmään {group}",
    "An administrator added you to group {group}" : "Ylläpitäjä lisäsi sinut ryhmään {group}",
    "An administrator added {user} to group {group}" : "Ylläpitäjä lisäsi käyttäjän {user} ryhmään {group}",
    "{actor} removed you from group {group}" : "{actor} poisti sinut ryhmästä {group}",
    "You removed {user} from group {group}" : "Poistit käyttäjän {user} ryhmästä {group}",
    "{actor} removed {user} from group {group}" : "{actor} poisti käyttäjän {user} ryhmästä {group}",
    "An administrator removed you from group {group}" : "Ylläpitäjä poisti sinut ryhmästä {group}",
    "An administrator removed {user} from group {group}" : "Ylläpitäjä poisti käyttäjän {user} ryhmästä {group}",
    "Your <strong>group memberships</strong> were modified" : "Sinun <strong>ryhmäjäsenyyksiä</strong> muokattiin",
    "{actor} changed your password" : "{actor} muutti salasanasi",
    "You changed your password" : "Muutit salasanasi",
    "Your password was reset by an administrator" : "Ylläpitäjä nollasi salasanasi",
    "Your password was reset" : "Salasanasi nollattiin",
    "{actor} changed your email address" : "{actor} muutti sähköpostiosoitteesi",
    "You changed your email address" : "Muutit sähköpostiosoitteesi",
    "Your email address was changed by an administrator" : "Ylläpitäjä muutti sähköpostiosoitteesi",
    "You created an app password for a session named \"{token}\"" : "Loit sovellussalasanan istunnolle nimeltä \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "Ylläpitäjä loi sovellussalasanan istunnolle nimeltä \"{token}\"",
    "You deleted app password \"{token}\"" : "Poistit sovellussalasanan \"{token}\"",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Nimesit sovellussalasanan \"{token}\" uudelleen muotoon \"{newToken}\"",
    "You granted filesystem access to app password \"{token}\"" : "Annoit pääsyn tiedostojärjestelmään sovellussalasanalle \"{token}\"",
    "You revoked filesystem access from app password \"{token}\"" : "Kumosit pääsyn tiedostojärjestelmään sovellussalasanalta \"{token}\"",
    "Security" : "Turvallisuus",
    "You successfully logged in using two-factor authentication (%1$s)" : "Kirjauduit onnistuneesti sisään kaksivaiheista tunnistautumista käyttäen (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Kirjautumisyritys kaksivaiheista tunnistautumista käyttäen epäonnistui (%1$s)",
    "Remote wipe was started on %1$s" : "Etätyhjennys aloitettiin %1$s",
    "Remote wipe has finished on %1$s" : "Etätyhjennys valmistui %1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>Salasanaasi</strong> tai <strong>sähköpostiosoitettasi</strong> muokattiin",
    "Settings" : "Asetukset",
    "Could not remove app." : "Sovellusta ei voitu poistaa.",
    "Could not update app." : "Sovellusta ei voitu päivittää.",
    "Wrong password" : "Väärä salasana",
    "Unable to change personal password" : "Henkilökohtaista salasanaa ei voitu vaihtaa",
    "Saved" : "Tallennettu",
    "Unable to change password. Password too long." : "Salasanaa ei voitu vaihtaa. Salasana on liian pitkä.",
    "Authentication error" : "Tunnistautumisvirhe",
    "Wrong admin recovery password. Please check the password and try again." : "Väärä ylläpitäjän salasana. Tarkista salasana ja yritä uudelleen.",
    "Administrator documentation" : "Ylläpidon dokumentaatio",
    "User documentation" : "Käyttäjädokumentaatio",
    "Invalid SMTP password." : "Virheellinen SMTP-salasana.",
    "Email setting test" : "Sähköpostiasetusten testaus",
    "Well done, %s!" : "Hyvin tehty, %s!",
    "If you received this email, the email configuration seems to be correct." : "Jos vastaanotit tämän viestin, sähköpostimääritykset vaikuttavat olevan kunnossa.",
    "Email could not be sent. Check your mail server log" : "Sähköpostia ei voitu lähettää. Tarkista sähköpostipalvelimen lokitiedosto",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Sähköpostia lähettäessä tapahtui virhe. Tarkista asetukset. (Virhe: %s)",
    "Disabled accounts" : "Käytöstä poistetut tilit",
    "Invalid account" : "Virheellinen tili",
    "Invalid mail address" : "Virheellinen sähköpostiosoite",
    "Settings saved" : "Asetukset tallennettu",
    "Unable to change full name" : "Koko nimen muuttaminen epäonnistui",
    "Unable to change email address" : "Sähköpostiosoitteen vaihtaminen ei onnistunut",
    "Unable to set invalid phone number" : "Virheellisen puhelinnumeron asettaminen ei onnistu",
    "Unable to set invalid website" : "Virheellisen verkkosivun asettaminen ei onnistu",
    "Some account data was invalid" : "Jokin tilidata oli virheellistä",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Jotta Twitter-tilisi on mahdollista vahvistaa, twiittaa seuraava viesti (varmista että lähetät viestin sellaisenaan ilman rivivaihtoja):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Jotta verkkosivustosi on mahdollista vahvistaa, aseta seuraava sisältö verkkosivustosi juureen '.well-known/CloudIdVerificationCode.txt' (varmista että koko teksti on yhdellä rivillä):",
    "Your password on %s was changed." : "Salasanasi osoitteessa %s on muutettu.",
    "Your password on %s was reset by an administrator." : "Ylläpitäjä muutti salasanasi osoitteessa %s.",
    "Your password on %s was reset." : "%s-salasanasi on nollattu.",
    "Password for %1$s changed on %2$s" : "Salasana käyttäjälle %1$s muutettu osoitteessa %2$s",
    "Password changed for %s" : "Salasana muutettu käyttäjälle %s",
    "If you did not request this, please contact an administrator." : "Jos et pyytänyt tätä, ota yhteyttä ylläpitäjään.",
    "Your email address on %s was changed." : "Sähköpostiosoitteesi osoitteessa %s on muutettu.",
    "Your email address on %s was changed by an administrator." : "Ylläpitäjä muutti sähköpostiosoitteesi osoitteessa %s.",
    "Email address for %1$s changed on %2$s" : "Sähköpostiosoite käyttäjälle %1$s muutettu osoitteessa %2$s",
    "Email address changed for %s" : "Sähköpostiosoite muutettu käyttäjälle %s",
    "The new email address is %s" : "Uusi sähköpostiosoite on %s",
    "Your %s account was created" : "%s-tilisi luotiin",
    "Welcome aboard" : "Tervetuloa mukaan",
    "Welcome aboard %s" : "Tervetuloa mukaan %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Tervetuloa %s-tilillesi. Voit lisätä, suojata ja jakaa tietojasi.",
    "Set your password" : "Aseta salasanasi",
    "Go to %s" : "Siirry %s-palveluun",
    "Install Client" : "Asenna sovellus",
    "Apps" : "Sovellukset",
    "Personal" : "Henkilökohtainen",
    "Administration" : "Ylläpito",
    "Users" : "Käyttäjät",
    "Additional settings" : "Lisäasetukset",
    "Assistant" : "Avustaja",
    "Administration privileges" : "Ylläpitäjän oikeudet",
    "Groupware" : "Groupware",
    "Overview" : "Yleiskuvaus",
    "Basic settings" : "Perusasetukset",
    "Sharing" : "Jakaminen",
    "Availability" : "Saatavuus",
    "Calendar" : "Kalenteri",
    "Personal info" : "Henkilökohtaiset tiedot",
    "Mobile & desktop" : "Mobiili ja työpöytä",
    "Artificial Intelligence" : "Tekoäly",
    "Email server" : "Sähköpostipalvelin",
    "Background jobs" : "Taustatyöt",
    "Unlimited" : "Rajoittamaton",
    "Verifying" : "Vahvistetaan",
    "Code integrity" : "Koodin eheys",
    "Some files have not passed the integrity check. {link1} {link2}" : "Jotkin tiedostot eivät läpäisseet eheystarkistusta. {link1} {link2}",
    "Cron errors" : "Cron-virheet",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Tietokannasta puuttuu primääriavaimia. Suuriin tauluihin primääriavainten lisääminen saattaa kestää kauan, ja sen vuoksi primääriavaimia ei lisätty automaattisesti. Suorita \"occ db:add-missing-primary-keys\" lisätäksesi puuttuvat primääriavaimet manuaalisesti samalla, kun instanssi pysyy käynnissä.",
    "Debug mode" : "Vianjäljitystila",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Tämä instanssi toimii vianjäljitystilassa. Käytä vianjäljitystilaa vain paikalliseen kehitykseen, älä koskaan käytä sitä tuotantoympäristössä.",
    "Internet connectivity" : "Internet-yhdistettävyys",
    "Disabled" : "Pois käytöstä",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "Vanha palvelinpuolen salausmenetelmä on käytössä. Suosittelemme sen ottamista pois käytöstä.",
    "Logging level" : "Lokitustaso",
    "Maintenance window start" : "Huoltoikkunan alku",
    "Memcache" : "Memcache",
    "You are not using MySQL" : "Et käytä MySQL:ää",
    "MySQL Unicode support" : "MySQL:n Unicode-tuki",
    "PHP APCu configuration" : "PHP APCu -määritys",
    "PHP default charset" : "PHP:n oletusmerkistö",
    "PHP set_time_limit" : "PHP:n set_time_limit",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHP-funktio \"set_time_limit\" ei ole käytettävissä. Tämä saattaa johtaa siihen, että skriptien suoritus päättyy ennenaikaisesti ja Nextcloud-asennus rikkoutuu. Funktion käyttäminen on erittäin suositeltavaa.",
    "Supported" : "Tuettu",
    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "PHP-asennuksessasi ei ole FreeType-tukea, ja siitä aiheutuu profiilikuvien sekä asetuskäyttöliittymän rikkoutuminen.",
    "PHP getenv" : "PHP:n getenv",
    "PHP memory limit" : "PHP:n muistiraja",
    "PHP modules" : "PHP-moduulit",
    "PHP opcache" : "PHP:n opcache",
    "PHP version" : "PHP-versio",
    "You are currently running PHP %s." : "Käytät PHP:n versiota %s.",
    "PHP \"output_buffering\" option" : "PHP:n \"output_buffering\"-asetus",
    "Push service" : "Push-palvelu",
    "Valid enterprise license" : "Kelvollinen enterprise-lisenssi",
    "Nextcloud configuration file is writable" : "Nextcloudin asetustiedosto on kirjoitettavissa",
    "HTTP headers" : "HTTP-otsakkeet",
    "Some headers are not set correctly on your instance" : "Jotkin otsakkeet eivät ole oikein asetettu instanssissasi",
    "Your server is correctly configured to send security headers." : "Palvelimesi on määritetty oikein tietoturvaotsakkeiden lähettämiseksi.",
    "Database version" : "Tietokannan versio",
    "Unknown database platform" : "Tuntematon tietokanta-alusta",
    "Architecture" : "Arkkitehtuuri",
    "64-bit" : "64-bit",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tietokantaasi ei suoriteta \"READ COMMITTED\"-transaktioeristystasolla. Tämä saattaa aiheuttaa ongelmia, kun useita toimintoja suoritetaan rinnakkaisesti.",
    ".well-known URLs" : ".well-known-URL-osoitteet",
    "Profile information" : "Profiilitiedot",
    "Nextcloud settings" : "Nextcloud-asetukset",
    "Enable" : "Käytä",
    "Machine translation" : "Konekäännös",
    "Image generation" : "Kuvien generointi",
    "Text processing" : "Tekstinkäsittely",
    "Task:" : "Tehtävä:",
    "Here you can decide which group can access certain sections of the administration settings." : "Tässä voit päättää, mitkä ryhmät voivat käyttää tiettyja osioita ylläpitäjän asetuksista.",
    "Unable to modify setting" : "Asetuksen muokkaaminen ei onnistu",
    "None" : "Ei mitään",
    "Allow apps to use the Share API" : "Salli sovellusten käyttää jakamisen ohjelmointirajapintaa",
    "Allow resharing" : "Salli uudelleenjakaminen",
    "Allow sharing with groups" : "Salli jakaminen ryhmien kanssa",
    "Restrict users to only share with users in their groups" : "Salli käyttäjien jakaa vain omassa ryhmässä olevien henkilöiden kesken",
    "Allow users to share via link and emails" : "Salli käyttäjien jakaa linkkien ja sähköpostin kautta",
    "Allow public uploads" : "Salli julkiset lähetykset",
    "Always ask for a password" : "Kysy aina salasanaa",
    "Enforce password protection" : "Pakota salasanasuojaus",
    "Limit sharing based on groups" : "Rajoita jakamista ryhmiin pohjautuen",
    "Allow sharing for everyone (default)" : "Salli jakaminen kaikille (oletus)",
    "Exclude some groups from sharing" : "Estä joitain ryhmiä jakamasta",
    "Limit sharing to some groups" : "Rajoita jakaminen tiettyihin ryhmiin",
    "Groups allowed to share" : "Ryhmät, joiden on sallittu jakaa",
    "Groups excluded from sharing" : "Ryhmät, jotka eivät saa jakaa",
    "Enforce expiration date" : "Pakota vanhenemispäivä",
    "Expire shares after x days" : "Vanhenna jaot x päivän jälkeen",
    "Set default expiration date for shares to other servers" : "Aseta oletuspäivä muille palvelimille tehtyjen jakojen lopettamiselle",
    "Default expiration time of shares in days" : "Jakojen oletusarvoinen vanhenemisaika päivissä",
    "Privacy settings for sharing" : "Jakamisen yksityisyysasetukset",
    "This text will be shown on the public link upload page when the file list is hidden." : "Tämä teksti näytetään julkisen linkin lähetyssivulla, kun tiedostolista on piilotettu.",
    "Default share permissions" : "Oletusjako-oikeudet",
    "Two-Factor Authentication" : "Kaksivaiheinen tunnistautuminen",
    "Enforce two-factor authentication" : "Pakota kaksivaiheinen tunnistautuminen",
    "Limit to groups" : "Rajoita ryhmiin",
    "Enforcement of two-factor authentication can be set for certain groups only." : "Kaksivaiheisen tunnistautumisen pakottaminen on mahdollista kohdentaa vain tietyille ryhmille.",
    "Two-factor authentication is enforced for all members of the following groups." : "Kaksivaiheisen tunnistautuminen on pakotettu kaikille seuraavien ryhmien jäsenille.",
    "Enforced groups" : "Pakotetut ryhmät",
    "Two-factor authentication is not enforced for members of the following groups." : "Kaksivaiheisen tunnistautuminen ei ole pakotettu seuraavien ryhmien jäsenille.",
    "Excluded groups" : "Poissuljetut ryhmät",
    "Save changes" : "Tallenna muutokset",
    "Default" : "Oletus",
    "Show details for {appName} app" : "Näytä sovelluksen {appName} tiedot",
    "Update to {update}" : "Päivitä versioon {update}",
    "Remove" : "Poista",
    "Featured" : "Poiminta",
    "This app is supported via your current Nextcloud subscription." : "Tämä sovellus on tuettu nykyisen Nextcloud-tilauksesi kautta.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Esitellyt sovellukset on yhteisön itsensä kehitettämiä. Ne tarjoavat keskeisiä toimintoja ja ovat valmiita tuotantokäyttöön.",
    "Community rating: {score}/5" : "Yhteisön arvostelu: {score}/5",
    "Disable all" : "Poista kaikki käytöstä",
    "Download and enable all" : "Lataa ja ota kaikki käyttöön",
    "All apps are up-to-date." : "Kaikki sovellukset ovat ajan tasalla.",
    "Icon" : "Kuvake",
    "Name" : "Nimi",
    "Version" : "Versio",
    "Level" : "Taso",
    "Actions" : "Toiminnot",
    "Results from other categories" : "Tulokset muista luokista",
    "No apps found for your version" : "Sovelluksia ei löytynyt versiollesi",
    "_%n app has an update available_::_%n apps have an update available_" : ["%n sovelluksella on päivitys saatavilla","%n sovelluksella on päivitys saatavilla"],
    "_Update_::_Update all_" : ["Päivitä","Päivitä kaikki"],
    "Failed to load groups" : "Ryhmien lataaminen epäonnistui",
    "Failed to create group" : "Ryhmän luonti epäonnistui",
    "Creating group…" : "Luodaan ryhmä…",
    "Create group" : "Luo ryhmä",
    "Group name" : "Ryhmän nimi",
    "Please enter a valid group name" : "Kirjoita kelvollinen ryhmän nimi",
    "Search groups…" : "Etsi ryhmiä…",
    "Loading groups…" : "Ladataan ryhmiä…",
    "Nothing to show" : "Ei mitään näytettävää",
    "Loading" : "Ladataan",
    "Fetching the latest news…" : "Noudetaan viimeisimpiä uutisia…",
    "Carousel" : "Karuselli",
    "Previous slide" : "Edellinen dia",
    "Next slide" : "Seuraava dia",
    "Choose slide to display" : "Valitse näytettävä dia",
    "{index} of {total}" : "{index}/{total}",
    "Daemon" : "Taustapalvelu",
    "Type" : "Tyyppi",
    "Display Name" : "Näyttönimi",
    "Learn more" : "Opi lisää",
    "Environment variables" : "Ympäristömuuttujat",
    "Confirm" : "Vahvista",
    "Cancel" : "Peru",
    "Description" : "Kuvaus",
    "View in store" : "Näytä kaupassa",
    "Visit website" : "Käy verkkosivustolla",
    "Admin documentation" : "Ylläpitäjän dokumentaatio",
    "Developer documentation" : "Kehittäjädokumentaatio",
    "Details" : "Tiedot",
    "All" : "Kaikki",
    "Limit app usage to groups" : "Rajoita sovelluskäyttö ryhmiin",
    "No results" : "Ei tuloksia",
    "Update to {version}" : "Päivitä versioon {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Tätä sovellusta ei voi asentaa, koska seuraavat riippuvuudet eivät täyty:",
    "Author" : "Tekijä",
    "Categories" : "Luokat",
    "Resources" : "Resurssit",
    "Documentation" : "Dokumentaatio",
    "Report a bug" : "Ilmoita viasta",
    "Request feature" : "Ehdota ominaisuutta",
    "Ask questions or discuss" : "Esitä kysymyksiä tai keskustele",
    "Rate the app" : "Arvostele sovellus",
    "Rate" : "Arvostele",
    "Changelog" : "Muutosloki",
    "Google Chrome for Android" : "Google Chrome Android-laitteelle",
    "{productName} iOS app" : "{productName}in iOS-sovellus",
    "{productName} Android app" : "{productName}in Android-sovellus",
    "{productName} Talk for iOS" : "{productName} Talk iOS:lle",
    "{productName} Talk for Android" : "{productName} Talk Androidille",
    "This session" : "Tämä istunto",
    "{client} - {version} ({system})" : "{client} - {version} ({system})",
    "{client} - {version}" : "{client} - {version}",
    "Device name" : "Laitteen nimi",
    "Save new name" : "Tallenna uusi nimi",
    "Marked for remote wipe" : "Merkitty etätyhjennettäväksi",
    "Device settings" : "Laiteasetukset",
    "Allow filesystem access" : "Salli pääsy tiedostojärjestelmään",
    "Rename" : "Nimeä uudelleen",
    "Revoke" : "Peru oikeus",
    "Wipe device" : "Tyhjennä laite",
    "Device" : "Laite",
    "Last activity" : "Viimeksi käytetty",
    "Devices & sessions" : "Laitteet ja istunnot",
    "Web, desktop and mobile clients currently logged in to your account." : "Verkko-, työpöytä- ja mobiililaitteet, jotka ovat parhaillaan kirjautuneet tilillesi.",
    "Error while creating device token" : "Virhe laitepolettia luotaessa",
    "App name" : "Sovelluksen nimi",
    "Create new app password" : "Luo uusi sovellussalasana",
    "App password copied!" : "Sovellussalasana kopioitu!",
    "Copy app password" : "Kopioi sovellussalasana",
    "Login name copied!" : "Kirjautumisnimi kopioitu!",
    "Copy login name" : "Kopioi kirjautumisnimi",
    "Could not copy app password. Please copy it manually." : "Sovellussalasanaa ei voitu kopioida. Kopioi se manuaalisesti.",
    "Could not copy login name. Please copy it manually." : "Kirjautumisnimeä ei voitu kopioida. Kopioi se manuaalisesti.https://app.transifex.com/nextcloud/nextcloud/settings-1/",
    "New app password" : "Uusi sovellussalasana",
    "Login" : "Kirjaudu",
    "Password" : "Salasana",
    "Show QR code for mobile apps" : "Näytä QR-koodi mobiilisovelluksia varten",
    "Use system cron service to call the cron.php file every 5 minutes." : "Käytä järjestelmän cron-palvelua cron.php-skriptin suorittamiseen 5 minuutin välein",
    "Last job execution ran {time}. Something seems wrong." : "Viimeisimmän työn suoritus {time}. Jokin vaikuttaa olevan pielessä.",
    "Last job ran {relativeTime}." : "Viimeisin työ ajettiin {relativeTime}.",
    "AJAX" : "AJAX",
    "Cron (Recommended)" : "Cron (suositeltu)",
    "Unable to update profile default setting" : "Profiilin oletusasetuksen päivittäminen ei onnistunut",
    "Profile" : "Profiili",
    "Password confirmation is required" : "Salasanavahvistus vaaditaan",
    "Server-side encryption" : "Palvelinpään salaus",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Palvelimelle ladatut tiedostot voidaan salata. Salaus aiheuttaa muun muassa palvelimen suorituskyvyn laskua, joten ota salaus käyttöön vain tarvittaessa.",
    "Enable server-side encryption" : "Käytä palvelinpään salausta",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Salausmoduulia ei ole käytössä. Ota salausmoduuli käyttöön sovellusvalikosta.",
    "Select default encryption module:" : "Valitse oletuksena käytettävä salausmoduuli:",
    "Enable encryption" : "Käytä salausta",
    "Please read carefully before activating server-side encryption:" : "Lue tarkasti, ennen kuin otat palvelinpään salauksen käyttöön:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Kun salaus on otettu käyttöön, käyttöönoton jälkeen palvelimelle ladatut tiedostot salataan palvelimen ollessa lepotilassa. Salauksen ottaminen pois päältä myöhemmin on mahdollista vain, jos aktiivinen salausmoduuli tukee toiminta ja kaikki muut vaatimukset (kuten palautusavaimen asettaminen) täyttyvät.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Salaus sellaisenaan ei takaa järjestelmäsi turvallisuutta. Tutustu dokumentaation saadaksesi lisätietoja, miten salaussovellus toimii ja nähdäksesi tuettuja käyttötapauksia.",
    "Be aware that encryption always increases the file size." : "Ota huomioon, että salaus kasvattaa aina tiedostojen kokoa.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Säännöllisten varmuuskopioiden ottaminen on erittäin tärkeää. Jos olet ottanut salauksen käyttöön, huolehdi salausavainten varmuuskopioinnista.",
    "This is the final warning: Do you really want to enable encryption?" : "Tämä on viimeinen varoitus: haluatko varmasti ottaa salauksen käyttöön?",
    "Failed to delete group \"{group}\"" : "Ryhmän \"{group}\" poistaminen epäonnistui",
    "Please confirm the group removal" : "Vahvista ryhmän poistaminen",
    "Submit" : "Lähetä",
    "Rename group" : "Nimeä ryhmä uudelleen",
    "Delete group" : "Poista ryhmä",
    "Current password" : "Nykyinen salasana",
    "New password" : "Uusi salasana",
    "Change password" : "Vaihda salasana",
    "Choose your profile picture" : "Valitse profiilikuva",
    "Please select a valid png or jpg file" : "Valitse kelvollinen png- tai jpg-tiedosto",
    "Error setting profile picture" : "Virhe profiilikuvaa asettaessa",
    "Error cropping profile picture" : "Virhe profiilikuvaa rajatessa",
    "Error saving profile picture" : "Virhe profiilikuvaa tallentaessa",
    "Error removing profile picture" : "Virhe profiilikuvaa poistaessa",
    "Your profile picture" : "Profiilikuvasi",
    "Upload profile picture" : "Lähetä profiilikuva",
    "Choose profile picture from Files" : "Valitse profiilikuva tiedostoista",
    "Remove profile picture" : "Poista profiilikuva",
    "The file must be a PNG or JPG" : "Tiedoston tulee olla PNG tai JPG",
    "Picture provided by original account" : "Kuvan tarjoaa alkuperäinen tili",
    "Set as profile picture" : "Aseta profiilikuvaksi",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "Ota huomioon, että profiilikuvasi päivittyminen kaikkialle saattaa kestää jopa 24 tuntia.",
    "Your biography. Markdown is supported." : "Esittelytekstisi. Markdown on tuettu.",
    "Unable to update date of birth" : "Syntymäpäivää ei voitu päivittää",
    "Enter your date of birth" : "Kirjoita syntymäpäiväsi",
    "You are using {s}{usage}{/s}" : "Käytössäsi on {s}{usage}{/s}",
    "You are using {s}{usage}{/s} of {s}{totalSpace}{/s} ({s}{usageRelative}%{/s})" : "Käytössäsi on {s}{usage}{/s}/{s}{totalSpace}{/s} ({s}{usageRelative}%{/s})",
    "You are a member of the following groups:" : "Olet seuraavien ryhmien jäsen:",
    "Your full name" : "Koko nimesi",
    "Email options" : "Sähköpostiasetukset",
    "Remove primary email" : "Poista ensisijainen sähköpostiosoite",
    "Delete email" : "Poista sähköposti",
    "This address is not confirmed" : "Tätä osoitetta ei ole vahvistettu",
    "Unset as primary email" : "Poista ensisijaisesta sähköpostista",
    "Set as primary email" : "Aseta ensisijaiseksi sähköpostiosoitteeksi",
    "Additional email address {index}" : "Lisäsähköpostiosoite {index}",
    "Unable to delete primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu poistaa",
    "Unable to update primary email address" : "Ensisijaista sähköpostiosoitetta ei voitu päivittää",
    "Primary email for password reset and notifications" : "Ensisijainen sähköposti salasanan nollaamista ja ilmoituksia varten",
    "No email address set" : "Sähköpostiosoitetta ei ole asetettu",
    "Your headline" : "Otsikkosi",
    "Unable to update language" : "Kieltä ei voi päivittää",
    "Languages" : "Kielet",
    "Help translate" : "Auta kääntämisessä",
    "No language set" : "Kieltä ei ole asetettu",
    "Unable to update locale" : "Maa-asetuston päivittäminen ei onnistu",
    "Locales" : "Aluekohtaiset asetukset",
    "Week starts on {firstDayOfWeek}" : "Viikon ensimmäinen päivä on {firstDayOfWeek}",
    "No locale set" : "Maa-asetustoa ei ole asetettu",
    "Your city" : "Kaupunkisi",
    "Your organisation" : "Organisaatiosi",
    "Your phone number" : "Puhelinnumerosi",
    "Edit your Profile visibility" : "Muokkaa profiilisi näkyvyyttä",
    "Enable profile" : "Ota profiili käyttöön",
    "Your role" : "Roolisi",
    "Timezone" : "Aikavyöhyke",
    "Your website" : "Verkkosivustosi",
    "Invalid value" : "Virheellinen arvo",
    "Add additional email" : "Lisää toissijainen sähköpostiosoite",
    "Add" : "Lisää",
    "Create" : "Luo",
    "Change" : "Muuta",
    "Delete" : "Poista",
    "Reshare" : "Jaa edelleen",
    "Large organization" : "Suuri organisaatio",
    "Big organization" : "Iso organisaatio",
    "Small organization" : "Pieni organisaatio",
    "University" : "Yliopisto",
    "School" : "Koulu",
    "Default language" : "Oletuskieli",
    "Common languages" : "Yleiset kielet",
    "Other languages" : "Muut kielet",
    "No accounts" : "Ei tilejä",
    "Loading accounts …" : "Ladataan tilejä…",
    "Account name will be autogenerated" : "Tilin nimi luodaan automaattisesti",
    "Account name (required)" : "Tilin nimi (pakollinen)",
    "New account" : "Uusi tili",
    "Display name" : "Näyttönimi",
    "Either password or email is required" : "Joko salasana tai sähköpostiosoite vaaditaan",
    "Password (required)" : "Salasana (pakollinen)",
    "Email (required)" : "Sähköposti (pakollinen)",
    "Email" : "Sähköpostiosoite",
    "Quota" : "Kiintiö",
    "Set account quota" : "Aseta tilin kiintiö",
    "Language" : "Kieli",
    "Set default language" : "Aseta oletuskieli",
    "Add new account" : "Lisää uusi tili",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} tili…","{userCount} tiliä…"],
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} tili","{userCount} tiliä"],
    "Scroll to load more rows" : "Vieritä ladataksesi enemmän rivejä",
    "Avatar" : "Profiilikuva",
    "Account name" : "Tilin nimi",
    "Group admin for" : "Ryhmäylläpitäjä ryhmille",
    "Storage location" : "Tallennustilan sijainti",
    "Last login" : "Viimeisin kirjautuminen",
    "Account actions" : "Tilin toiminnot",
    "{size} used" : "{size} käytetty",
    "Delete account" : "Poista tili",
    "Disable account" : "Poista tili käytöstä",
    "Enable account" : "Ota tili käyttöön",
    "Resend welcome email" : "Lähetä uudelleen tervetuloviesti",
    "Remote wipe of devices" : "Laitteiden etätyhjennys",
    "Wipe {userid}'s devices" : "Tyhjennä käyttäjän {userid} laitteet",
    "Wiped {userid}'s devices" : "Tyhjennetty käyttäjän {userid} laitteet",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "Poista täysin käyttäjän {userid} tili mukaan lukien henkilökohtaiset tiedostot, sovellusten tiedot jne.",
    "Account deletion" : "Tilin poistaminen",
    "Delete {userid}'s account" : "Poista käyttäjän {userid} tili",
    "Display name was successfully changed" : "Näyttönimi vaihdettiin onnistuneesti",
    "Password can't be empty" : "Salasana ei voi olla tyhjä",
    "Password was successfully changed" : "Salasana vaihdettiin onnistuneesti",
    "Email can't be empty" : "Sähköposti ei voi olla tyhjä",
    "Email was successfully changed" : "Sähköpostiosoite vaihdettiin onnistuneesti",
    "Welcome mail sent!" : "Tervetuloviesti lähetetty!",
    "Loading account …" : "Ladataan tiliä…",
    "Change display name" : "Vaihda näyttönimi",
    "Set new password" : "Aseta uusi salasana:",
    "Set new email address" : "Aseta uusi sähköpostiosoite",
    "Add account to group" : "Lisää tili ryhmään",
    "Select account quota" : "Valitse tilin kiintiö",
    "Set the language" : "Aseta kieli",
    "Done" : "Valmis",
    "Edit" : "Muokkaa",
    "Account management settings" : "Tilihallinnan asetukset",
    "Visibility" : "Näkyvyys",
    "Show language" : "Näytä kieli",
    "Show storage path" : "Näytä tallennustilan polku",
    "Show last login" : "Näytä viimeisin sisäänkirjautuminen",
    "Sorting" : "Lajittelu",
    "Send email" : "Lähetä sähköpostiviesti",
    "Send welcome email to new accounts" : "Lähetä Tervetuloa-sähköposti uusille tileille",
    "Defaults" : "Oletukset",
    "Default quota" : "Oletuskiintiö",
    "Select default quota" : "Valitse oletuskiintiö",
    "Server error while trying to complete WebAuthn device registration" : "Palvelinvirhe kun yritettiin suorittaa WebAuthn-laitteen rekisteröintiä",
    "Passwordless authentication requires a secure connection." : "Tunnistautuminen ilman salasanaa vaatii salatun yhteyden.",
    "Add WebAuthn device" : "Lisää WebAuthn-laite",
    "Please authorize your WebAuthn device." : "Valtuuta WebAuthn-laitteesi.",
    "Adding your device …" : "Lisätään laitettasi…",
    "Unnamed device" : "Nimetön laite",
    "Passwordless Authentication" : "Tunnistautuminen ilman salasanaa",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Aseta tilillesi tunnistautuminen ilman salasanaa FIDO2-standardia seuraten.",
    "No devices configured." : "Laitteita ei ole määritetty.",
    "The following devices are configured for your account:" : "Seuraavat laitteet on määritetty tilillesi:",
    "Your browser does not support WebAuthn." : "Selaimesi ei tue WebAuthn-standardia.",
    "Security & setup warnings" : "Turvallisuus- ja asetusvaroitukset",
    "Try again" : "Yritä uudelleen",
    "All checks passed." : "Läpäistiin kaikki tarkistukset.",
    "There are some errors regarding your setup." : "Asetuksiin liittyen on muutamia virheitä.",
    "There are some warnings regarding your setup." : "Asetuksiin liittyen on muutamia varoituksia.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Ylläpitäjänä voit hienosäätää jakamista. Katso dokumentaatiosta lisätietoa.",
    "Loading app list" : "Ladataan sovellusluetteloa",
    "Loading categories" : "Ladataan luokkia",
    "Developer documentation ↗" : "Kehittäjien dokumentaatio ↗",
    "Version {version}, {license}-licensed" : "Versio {version}, lisenssi {license}",
    "Version {version}" : "Versio {version}",
    "Apply" : "Toteuta",
    "All accounts" : "Kaikki tilit",
    "Admins" : "Ylläpitäjät",
    "Account group: {group}" : "Tiliryhmä: {group}",
    "Account management" : "Tilihallinta",
    "Sending…" : "Lähetetään…",
    "Email sent" : "Sähköposti lähetetty",
    "Location" : "Sijainti",
    "Profile picture" : "Profiilikuva",
    "About" : "Tietoja",
    "Date of birth" : "Syntymäpäivä",
    "Full name" : "Koko nimi",
    "Additional email" : "Toissijainen sähköpostiosoite",
    "Fediverse (e.g. Mastodon)" : "Fediverse (esim. Mastodon)",
    "Headline" : "Otsikko",
    "Organisation" : "Organisaatio",
    "Phone number" : "Puhelinnumero",
    "Role" : "Rooli",
    "X (formerly Twitter)" : "X (aiemmin Twitter)",
    "Website" : "Verkkosivusto",
    "Profile visibility" : "Profiilin näkyvyys",
    "Locale" : "Aluekohtainen asetus",
    "First day of week" : "Viikon ensimmäinen päivä",
    "timezone" : "aikavyöhyke",
    "Your apps" : "Sovelluksesi",
    "Active apps" : "Aktiiviset sovellukset",
    "Disabled apps" : "Käytöstä poistetut sovellukset",
    "Updates" : "Päivitykset",
    "App bundles" : "Sovelluskokoelmat",
    "Featured apps" : "Esitellyt sovellukset",
    "Supported apps" : "Tuetut sovellukset",
    "Show to everyone" : "Näytä kaikille",
    "Show to logged in accounts only" : "Näytä vain sisäänkirjautuneille tileille",
    "Hide" : "Piilota",
    "Download and enable" : "Lataa ja ota käyttöön",
    "Disable" : "Poista käytöstä",
    "Allow untested app" : "Salli testaamaton sovellus",
    "The app will be downloaded from the App Store" : "Sovellus ladataan sovelluskaupasta",
    "Unknown" : "Tuntematon",
    "Never" : "Ei koskaan",
    "Could not register device: Network error" : "Laitetta ei voitu rekisteröidä: verkkovirhe",
    "Could not register device: Probably already registered" : "Laitetta ei voitu rekisteröidä: luultavasti jo rekisteröity",
    "Could not register device" : "Laitetta ei voitu rekisteröidä",
    "An error occurred during the request. Unable to proceed." : "Pyynnön aikana tapahtui virhe. Jatkaminen ei onnistu.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Virhe: Sovellusta ei voida ottaa käyttöön, koska se aiheuttaa palvelimen epävakauden",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Sovellus on käytössä, mutta se tulee päivittää. Sinut ohjataan sovelluksen päivityssivulle viiden sekunnin kuluttua.",
    "Do you really want to wipe your data from this device?" : "Haluatko varmasit tyhjentää tiedot tältä laitteelta?",
    "Confirm wipe" : "Vahvista tyhjentäminen",
    "Could not delete the app token" : "Sovelluspolettia ei voitu poistaa",
    "Error while wiping the device with the token" : "Virhe tyhjennettäessä laitetta polettia käyttäen",
    "Error while updating device token name" : "Virhe laitepoletin nimeä päivittäessä",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Verkostasi tehtiin liian monta pyyntöä. Yritä myöhemmin uudelleen tai ole yhteydessä ylläpitäjään, jos tämä on mielestäsi virhe.",
    "Error" : "Virhe",
    "Account documentation" : "Tilin dokumentaatio",
    "Administration documentation" : "Ylläpidon dokumentaatio",
    "Forum" : "Keskustelupalsta",
    "General documentation" : "Yleinen dokumentaatio",
    "Legal notice" : "Lainopillinen huomautus",
    "Privacy policy" : "Tietosuojakäytäntö",
    "SSL" : "SSL",
    "Open documentation" : "Avaa dokumentaatio",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "On tärkeää määrittää sähköpostipalvelinasetukset, jotta voidaan lähettää muun muassa salasanan palautus- ja ilmoitussähköpostiviestejä.",
    "Send mode" : "Lähetystila",
    "Encryption" : "Salaus",
    "Sendmail mode" : "Sendmail-tila",
    "From address" : "Lähettäjän osoite",
    "Server address" : "Palvelimen osoite",
    "Port" : "Portti",
    "Authentication" : "Tunnistautuminen",
    "Authentication required" : "Tunnistautuminen vaaditaan",
    "Credentials" : "Tilitiedot",
    "SMTP Password" : "SMTP-salasana",
    "Save" : "Tallenna",
    "Test and verify email settings" : "Testaa ja vahvista sähköpostiasetukset",
    "Reasons to use Nextcloud in your organization" : "Nextcloudin käytön edut organisaatiossasi",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Kehityksestä on vastannut {communityopen}Nextcloud-yhteisö{linkclose}, {githubopen}lähdekoodi{linkclose} on {licenseopen}AGPL-lisensoitu{linkclose}.",
    "Like our Facebook page" : "Tykkää Facebook-sivustamme",
    "Follow us on Mastodon" : "Seuraa meitä Mastodonissa",
    "Check out our blog" : "Lue blogia",
    "Subscribe to our newsletter" : "Tilaa uutiskirje",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "Tätä yhteisöjulkaisua Nextcloudista ei tueta, ja pikailmoitukset eivät ole saatavilla.",
    "Use a second factor besides your password to increase security for your account." : "Käytä toista vaihetta salasanasi lisäksi parantaaksesi tilisi tietoturvaa.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Jos yhdistät kolmannen osapuolen ohjelmia Nextcloudiin, määritä niille sovellussalasanat ennen kaksiosaisen todentamismenetelmän käyttöönottoa.",
    "File locking" : "Tiedostolukitus",
    "Set default expiration date for shares" : "Aseta oletusarvoinen vanhenemispäivä jaoille",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt minimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Tämä sovellus ei ole määritellyt maksimi Nextcloud-versiota. Tämä tulee olemaan ongelma tulevaisuudessa.",
    "Your biography" : "Sinun elämäkertasi",
    "You are using <strong>{usage}</strong>" : "Käytössäsi on <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "Käytössäsi on <strong>{usage}</strong>/<strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "Laitteen kadotessa tai organisaatiosta poistuessa voidaan käyttäjälle {userid} Nextcloudiin yhdistetyistä laitteista pyyhkiä  tiedot. Toimii vain laitteiden ollessa yhteydessä Internetiin.",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Sovellusta ei ole merkattu yhteensopivaksi Nextcloud-versiosi kanssa. Voit kuitenkin jatkaa ja asentaa sovelluksen. Huomioi, että sovellus ei välttämättä toimi odotetusti.",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "Turvallisuuden ja suorituskyvyn vuoksi on tärkeää, että palvelimen asetukset ovat määritetty oikein. Apuna on joitain automaattisia tarkistuksia. Lue lisätietoja linkitetystä dokumentaatiosta.",
    "Checking for system and security issues." : "Tarkistetaan mahdollisia järjestelmä- ja tietoturvaongelmia.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Lue tarkkaan <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">asennusohjeet ↗</a>, ja tarkista virheet sekä varoitukset <a href=\"%2$s\">lokista</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Tarkista Nextcloudisi turvallisuus käyttäen <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">tietoturvakartoitustamme ↗</a>."
},
"nplurals=2; plural=(n != 1);");
